@@ -8,9 +8,9 @@
 
 
 
-local unpack = table.unpack or unpack; --luacheck: ignore 113
+local unpack = table.unpack or unpack; --luacheck: ignore 113 143
 local t_insert = table.insert;
-function import(module, ...)
+function _G.import(module, ...)
 	local m = package.loaded[module] or require(module);
 	if type(m) == "table" and ... then
 		local ret = {};
